Change Log
----------

..
   All enhancements and patches to cookiecutter-django-app will be documented
   in this file.  It adheres to the structure of http://keepachangelog.com/ ,
   but in reStructuredText instead of Markdown (for ease of incorporation into
   Sphinx documentation and the PyPI description).
   
   This project adheres to Semantic Versioning (http://semver.org/).

.. There should always be an "Unreleased" section for changes pending release.

Unreleased
~~~~~~~~~~

[0.1.1] - 2016-10-11
~~~~~~~~~~~~~~~~~~~~

Changed
_______

* Fix Travis configuration for PyPI deployments.
* Switch from the Read the Docs Sphinx theme to the Open edX one for documentation.


[0.1.0] - 2016-10-07
~~~~~~~~~~~~~~~~~~~~

Added
_____

* First attempt to release on PyPI.
